<p><a href="{% url 'form_error' %}">form error</a></p>
<p><a href="{% url 'error_result' %}">error result</a></p>
<p><a href="{% url 'error_result_object_does_not_exist' %}">error result obbject does not exist</a></p>
<p><a href="{% url 'result_view_success' %}">result view success</a></p>
<p><a href="{% url 'result_view_danger' %}">result view danger</a></p>
<p><a href="{% url 'result_view_info' %}">result view info</a></p>

